package org.meandre.tools.serialization.java;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;

import org.junit.Test;

public class JavaSerializationTest {

	@Test
	public void testJavaSerialization () throws IOException {
		final int MAX_SIZE = 10000;
		final int REP = 50;
		final int INC = 100;
		
		System.out.println("Java serialization times");
		for ( int i=INC ; i<=MAX_SIZE ; i+=INC ) {
			TargetObjectSerializable tos = new TargetObjectSerializable(i,i);
			long lAccTime = 0;
			long lSize = 0;
			long lTmp;
			ByteArrayOutputStream baos;
			ObjectOutputStream out;
			for ( int j=0 ; j<REP ; j++ ) {
				baos = new ByteArrayOutputStream();
				out = new ObjectOutputStream(baos);
				lTmp = System.currentTimeMillis();
				out.writeObject(tos);
				lTmp -= System.currentTimeMillis();
				out.close();
				lAccTime -= lTmp;
				lSize = baos.size(); 
			}
			System.out.println(""+i+"\t"+(((double)lAccTime)/REP)+"\t"+lSize);
		}
	}


	@Test
	public void testJavaDeserialization () throws IOException, ClassNotFoundException {
		final int MAX_SIZE = 10000;
		final int REP = 50;
		final int INC = 100;
		
		System.out.println("Java deserialization times");
		for ( int i=INC ; i<=MAX_SIZE ; i+=INC ) {
			TargetObjectSerializable tos = new TargetObjectSerializable(i,i);
			ByteArrayOutputStream baos = new ByteArrayOutputStream();
			ObjectOutputStream out = new ObjectOutputStream(baos);
			out.writeObject(tos);
			out.close();
			ByteArrayInputStream bais;
			ObjectInputStream ois;
			long lAccTime = 0;
			long lTmp;
			for ( int j=0 ; j<REP ; j++ ) {
				bais = new ByteArrayInputStream(baos.toByteArray());
				ois = new ObjectInputStream(bais);
				lTmp = System.currentTimeMillis();
				ois.readObject();
				lTmp -= System.currentTimeMillis();
				lAccTime -= lTmp;
			}
			System.out.println(""+i+"\t"+(((double)lAccTime)/REP));
		}
	}
}
