package org.meandre.tools.serialization.proto;

import org.junit.Test;
import org.meandre.tools.serialization.proto.TargetObjectProtoOuter.TargetObjectProto;
import org.meandre.tools.serialization.proto.TargetObjectProtoOuter.TargetObjectProto.Builder;

import com.google.protobuf.InvalidProtocolBufferException;


public class ProtoSerializationTest {

	private TargetObjectProto createProtoObject(int iMax) {
		Builder top = TargetObjectProto.newBuilder();
		for (int i=0 ; i<iMax ; i++ ) {
			top.addIa(0);
			top.addSa("Dummy text");
		}
		return top.build();
	}

	@Test
	public void testProtoSerialization () {
		final int MAX_SIZE = 10000;
		final int REP = 50;
		final int INC = 100;
		
		System.out.println("Proto serialization times");
		for ( int i=INC ; i<=MAX_SIZE ; i+=INC ) {
			TargetObjectProto top = createProtoObject(i);
			long lAccTime = 0;
			long lSize = 0;
			long lTmp;
			byte [] ba;
			for ( int j=0 ; j<REP ; j++ ) {
				lTmp = System.currentTimeMillis();
				ba = top.toByteArray();
				lTmp -= System.currentTimeMillis();
				lAccTime -= lTmp;
				lSize = ba.length; 
			}
			System.out.println(""+i+"\t"+(((double)lAccTime)/REP)+"\t"+lSize);
		}
	}


	@Test
	public void testProtoDeserialization () throws InvalidProtocolBufferException {
		final int MAX_SIZE = 10000;
		final int REP = 50;
		final int INC = 100;
		
		System.out.println("Proto deserialization times");
		for ( int i=INC ; i<=MAX_SIZE ; i+=INC ) {
			TargetObjectProto top = createProtoObject(i);
			byte [] ba = top.toByteArray();
			long lAccTime = 0;
			long lTmp;
			for ( int j=0 ; j<REP ; j++ ) {
				lTmp = System.currentTimeMillis();
				TargetObjectProto.parseFrom(ba);
				lTmp -= System.currentTimeMillis();
				lAccTime -= lTmp;
			}
			System.out.println(""+i+"\t"+(((double)lAccTime)/REP));
		}
	}

	
}
